Mouse button 1
@@ -75,7 +76,7 @@
- Fl_Input platform specific keyboard bindings.
+ Platform specific keyboard bindings.
Windows/Linux
Mac
diff --git a/FL/Fl_Tree.H b/FL/Fl_Tree.H
index d35762c5f..9f4c685cd 100644
--- a/FL/Fl_Tree.H
+++ b/FL/Fl_Tree.H
@@ -235,7 +235,7 @@
/// The following table lists keyboard bindings for navigating the tree:
///
///
-/// Fl_Tree keyboard bindings.
+/// Keyboard bindings.
///
/// Keyboard
/// FL_TREE_SELECT_MULTI
diff --git a/KNOWN_BUGS.html b/KNOWN_BUGS.html
index 56e7ae17f..18e04d3f7 100644
--- a/KNOWN_BUGS.html
+++ b/KNOWN_BUGS.html
@@ -1,23 +1,22 @@
-
- Known Bugs and Feature Requests - Fast Light Toolkit (FLTK) 1.3.4
+
+
+ Known Bugs and Feature Requests - Fast Light Toolkit (FLTK) 1.3.5
-
-
-
-Known Bugs and Feature Requests in FLTK 1.3.4
+Known Bugs and Feature Requests in FLTK 1.3.5
This is a list of open STR's (Software Trouble Reports) and RFE's
-(Requests for Enhancement) at the time of the release of FLTK 1.3.4 (Nov. 2016).
+(Requests for Enhancement) at the time of the release of FLTK 1.3.5 (Jan. 2019).
The current list can be viewed online at FLTK's
-Development Roadmap .
-FLTK 1.3.4 is expected to be the last release in the 1.3.x series. Only
-very serious bugs may be addressed in a future 1.3.5 release.
+Development Roadmap .
+FLTK 1.3.5 is expected to be the last release in the 1.3.x series. Only
+very serious bugs may be addressed in a future 1.3.6 release.
+
All open STR's and RFE's of FLTK 1.3.x will be considered for FLTK 1.4.0,
if possible.
@@ -25,1188 +24,21 @@ if possible.
and/or patches online.
-
+
+
+
-FLTK 1.3 is the CURRENT STABLE DEVELOPMENT BRANCH based on FLTK
-1.1.10. It adds internationalization, UTF-8 (Unicode), printing support,
- Doxygen based documentation, and several new widgets including
-Fl_Native_File_Chooser, Fl_Table, and Fl_Tree.
-
-
+FLTK 1.3 is the LATEST STABLE BRANCH based on FLTK 1.1.10. It adds internationalization,
+ UTF-8 (Unicode), printing support, Doxygen based documentation, and several new widgets
+ including Fl_Native_File_Chooser, Fl_Table, and Fl_Tree. FLTK 1.3 is no longer in active
+ development but still gets some important bug fixes (and for instance new macOS support).
+
+
-
-
-2682 Vertical scrollbar of Fl_Text_Editor have a strange behavior. Or is bug? Core Library New MOD
-
-
-
-2862 Fl_Table keyboard nav issue: can't use tab to navigate off the widget Core Library Pending MOD
-
-
-
-2895 Fl_Tree: SINGLE mode selection issues Core Library Active MOD
-
-
-
-2944 Mac OS X Fl_Gl_Window bugs - all FLTK versions Core Library Pending MOD
-
-
-
-2961 1.3 very slow on X11 with Unicode locale New MOD
-
-
-
-3001 Flickering while resizing New MOD
-
-
-
-3018 Selects unclicked cells/rows/cols in the Fl_Table. Core Library Pending MOD
-
-
-
-3030 resize behavior of widgets in an Fl_Tree Core Library Pending MOD
-
-
-
-3048 Fl_Help_Dialog is clipping arrows on vertical scrollbar New MOD
-
-
-
-3170 Fl_Table_Row callback not called Core Library New MOD
-
-
-
-3188 Callback added using Fl::add_timeout is not called (X11) Core Library Active MOD
-
-
-
-3205 Fl_Native_File_Chooser highlighting doesn't follow file type choice New MOD
-
-
-
-3227 Fl_Help_View incorrectly displays "Table Heading" and "Horizontal Line" Core Library New MOD
-
-
-
-3232 fl_dnd_win32 compilation error New MOD
-
-
-
-3244 Fl_Window 's Label can't be aligned in MS Windows 10 New MOD
-
-
-
-3252 Fl_Native_File_Chooser and Fl_Gl_Window on MacOS X New MOD
-
-
-
-3259 Incompatibilty with tmux on OSX New MOD
-
-
-
-3310 Please move code to github None New MOD
-
-
-
-3321 [X11/Xft] Overlapping lines (font rendering problems) New MOD
-
-
-
-3337 Fl_Text_Display: sometimes selection doesn't work New MOD
-
-
-
-3346 FreeBSD/NetBSD: cannot build with make without running configure before Build Files New MOD
-
-
-
-2714 FLTK headers have shadow lint Core Library Pending LOW
-
-
-
-2788 Annoying Fl_Text_Editor mouse cursor behavior Core Library New LOW
-
-
-
-2791 Minmum size for tiles in an Fl_Tile Core Library New LOW
-
-
-
-2797 X errors occur when XDBE disabled + Fl_Double_Windows resized to zero on W or H Core Library New LOW
-
-
-
-2798 X11 coordinate clipping - label X11 New LOW
-
-
-
-2823 Fl_Preferences unecessary setting of dirty attribute Core Library New LOW
-
-
-
-2828 Fl_Tree RFE's Core Library New LOW
-
-
-
-2844 Fl_Text_Display: needs keyboard nav for caret motion and keyboard selection Core Library New LOW
-
-
-
-2880 menu popup() positioning New LOW
-
-
-
-2883 submenu positioning New LOW
-
-
-
-2892 Fl_Text_Display::position_to_line(): Consistency check ptvl failed New LOW
-
-
-
-2901 Fl_Browser format codes New LOW
-
-
-
-2908 Menu_::find_index(const char*) doesn't handle escape sequence correctly Core Library Pending LOW
-
-
-
-2909 Fl_Tile does not pass FL_RELEASE event to children New LOW
-
-
-
-2940 Docs for label() '@' symbols need some improvement Core Library New LOW
-
-
-
-2978 FL_DND_LEAVE not passed to handle() function Core Library Pending LOW
-
-
-
-2989 'Up' and 'Down' keys don't work in Fl_Spinner at all New LOW
-
-
-
-3075 Fl_Tabs don't show labels for Fl_Window children Core Library New LOW
-
-
-
-3077 fl_normal_measure does not give correct size for FL_ALIGN_IMAGE_NEXT_TO_TEXT New LOW
-
-
-
-3080 Implicit type conversion from int64 to int32 in fl_draw New LOW
-
-
-
-3108 [patch] Constify XPM pointers Core Library Pending LOW
-
-
-
-3119 Fl_Gl_Window switched off Aero in Windows 7 New LOW
-
-
-
-3120 Roller should react to the mouse wheel Core Library New LOW
-
-
-
-3134 fl_clip_box fails on X11 with large coordinates New LOW
-
-
-
-3147 Assigning Ctrl+Shift+0 to a Fl_Sys_Menu_Bar item does not work using Visual Studio 2012 New LOW
-
-
-
-3175 Fl_Text_Editor overstrike mode doesn't behave as expected Core Library New LOW
-
-
-
-3186 fl_filename_match() inconsistent with case sensitivity New LOW
-
-
-
-3201 unix Fl_Window::show _NET_ACTIVE_WINDOW event needed to raise X11 New LOW
-
-
-
-3208 Memory leaks with fl_draw(int angle, ...) ? X11 Pending LOW
-
-
-
-3214 Fl_Tree::clear() does not delete widgets (only items) Core Library Pending LOW
-
-
-
-3220 Can select multiple items in Fl_Tree even in FL_TREE_SELECT_SINGLE mode Core Library Active LOW
-
-
-
-3225 Problem with shown directory in fl_file_chooser New LOW
-
-
-
-3248 Fl_Text_Editor Selection starts at wrong position after paste Core Library New LOW
-
-
-
-3261 FLTK and glutChangeToMenuEntry New LOW
-
-
-
-3273 Fl::screen_dpi() returns generic Xinerama values New LOW
-
-
-
-3282 Fl_Table::handle() returns 1 on right clicks New LOW
-
-
-
-3290 Fl_Help_Dialog does not number ordered lists New LOW
-
-
-
-3292 Fl_Browser: trouble pre-selecting item #1 with type() HOLD or SELECT New LOW
-
-
-
-3293 show_item_top() causes tree redraw position bug New LOW
-
-
-
-3295 fluid -c is running GUI code (again), bad for headless operation FLUID New LOW
-
-
-
-3301 Fl_Text_Display::scroll(line) not working with wrap_mode() Core Library New LOW
-
-
-
-3323 Request for glutAddMenuEntry to have a const label argument New LOW
-
-
-
-3328 Fluid docs: GUI attributes text and Figure 9.8 out of date Documentation New LOW
-
-
-
-3334 Minor bug fixes to Fl_Tabs. New LOW
-
-
-
-3341 Fl_File_Chooser has no icons under more recent distributions New LOW
-
-
-
-3343 fluid "templates" needs docs FLUID New LOW
-
-
-
-829 Support for animated GIFs in Fl_GIF_Image Image Support New RFE
-
-
-
-2676 Enhance error reporting on broken Xft installations (was:fl_alert dialogs etc crashes in XftTextExtents32 on Solaris) X11 New RFE
-
-
-
-2728 Add test program to test for shadowed variables (-Wshadow) Test Framework New RFE
-
-
-
-2753 Capture enter as click on button with focus Core Library New RFE
-
-
-
-2755 Allow color change on Browser selection bar based on focus Core Library New RFE
-
-
-
-2756 New browser checkbox widget Core Library New RFE
-
-
-
-2757 Allows shortcuts on browser items Core Library New RFE
-
-
-
-2763 Full Selection Movement when using Keyboard in Browser Core Library New RFE
-
-
-
-2766 New configurable option to change symbol prefix character Core Library New RFE
-
-
-
-2767 Fix scrollbar visiblity from causing miscalcuation on select() Core Library New RFE
-
-
-
-2790 Patch allow fluid generate constructor without arguments for Widget_Class FLUID New RFE
-
-
-
-2792 Change of logic used on browser_ when no selection Core Library New RFE
-
-
-
-2793 Option to change FL_SHORTCUT logic Core Library New RFE
-
-
-
-2794 Fluid hacked FLUID New RFE
-
-
-
-2799 Menus can suddenly disappear Core Library Pending RFE
-
-
-
-2815 Implementation of Fl_Text_Display backdrop Core Library New RFE
-
-
-
-2817 Add a hook to track timeouts Core Library New RFE
-
-
-
-2821 MouseWheel acceleration patch OS support New RFE
-
-
-
-2824 Adding scroller animation to FLTK Core Library New RFE
-
-
-
-2838 Add Colors to FL_Text_Display (+ underscore + strikethru) Core Library New RFE
-
-
-
-2841 preventing of unintentional removing in Fluid FLUID New RFE
-
-
-
-2842 putting new widget on place of user's click FLUID New RFE
-
-
-
-2843 Fluid: "space evenly" makes the same distance between pairs FLUID New RFE
-
-
-
-2867 ADding bgcolor to Style_Table_Entry Core Library New RFE
-
-
-
-2875 More general methods to select fonts with attributes BOLD/ITALIC (Patch supplied) X11 New RFE
-
-
-
-2876 Make xft font sorting work (patch supplied) X11 New RFE
-
-
-
-2882 a minimum knob-size for Fl_Scrollbar widget New RFE
-
-
-
-2894 problem with pressed_menu_button_ New RFE
-
-
-
-2896 Better looking menu dividers New RFE
-
-
-
-2902 FL_HOLD_BROWSER selection positioning New RFE
-
-
-
-2923 New Cursors for fltk-1.3 New RFE
-
-
-
-2924 New Cursors for fltk-1.3 and fltk-3.0 New RFE
-
-
-
-2926 Remove hardcoded extra pixels from menu window size New RFE
-
-
-
-2927 Please replace LEADING constant in FL_Menu.cxx to something changeable New RFE
-
-
-
-2929 New Fl_I18n class to support internationalization of FLTK apps Core Library New RFE
-
-
-
-2936 fluid: needs mods to allow defining a 'namespace' New RFE
-
-
-
-2941 RFE: fl_text_extents(): support multiple lines Core Library New RFE
-
-
-
-2950 Menu Item behaviour New RFE
-
-
-
-2952 fluid - Adding win32 icon New RFE
-
-
-
-2953 Add append() method to Fl_Multiline_Output and friends New RFE
-
-
-
-2980 Fl::event_text() returns no meaningful value for FL_DND_ENTER and FL_DND_DRAG on Windows New RFE
-
-
-
-2981 Fl::event_text() returns "<unknown>" for FL_DND_ENTER and FL_DND_DRAG on X11 New RFE
-
-
-
-2992 New widget: Fl_Gl_Window_Group New RFE
-
-
-
-3003 class Fl_Toggle_Browser for fltk-1.3.x . New RFE
-
-
-
-3004 The class Fl_Check_Browser needs more correct the `int handle(int event)' method . New RFE
-
-
-
-3007 Suggestion for improvement to the standard file-chooser. New RFE
-
-
-
-3015 Allow hiding scrollbars in Fl_Help_View New RFE
-
-
-
-3017 FLTK & icons for each scheme. New RFE
-
-
-
-3020 Function for blending two images with different depth of color. New RFE
-
-
-
-3021 Logotip for FLTK New RFE
-
-
-
-3029 Build FLTK via Clang compiler and native Windows tools New RFE
-
-
-
-3052 Fl_Tabs enhancement: tab scrolling when there are too many tabs New RFE
-
-
-
-3053 Fl_Tabs enhancement - being able to move tabs around New RFE
-
-
-
-3074 Patch for Browser supporting copy to clipboard of selected lines New RFE
-
-
-
-3076 Can't set align for tabs New RFE
-
-
-
-3092 Fl_Pack: add right-to-left and bottom-to-top packing Core Library New RFE
-
-
-
-3094 Fl_Scroll: to control the hscrollbar by wheel of mouse New RFE
-
-
-
-3112 whether we should define these macros in FLTK sourse files?(strdup stricmp...) New RFE
-
-
-
-3126 Image resizing algorithm Image Support New RFE
-
-
-
-3136 Patch to add an option to the Fl_Native_file_Chooser and Fl_File_Chooser to allow selection of either a file or a directory New RFE
-
-
-
-3148 Fl_X::make(window) shows the window on screen on OS X New RFE
-
-
-
-3159 multiple highlight on Fl_Text_Display New RFE
-
-
-
-3171 Equivalent of names.h for Fl_Table::TableContext enum Core Library New RFE
-
-
-
-3174 Scrollbar of deactivated Fl_Text_Editor not working Core Library New RFE
-
-
-
-3180 Linux printer panel, 3 problems New RFE
-
-
-
-3181 3d pie chart New RFE
-
-
-
-3182 oxy patch Core Library New RFE
-
-
-
-3189 Diagonal cursors from themes for Linux (patch) New RFE
-
-
-
-3193 Change the Background Color of Checkboxes and Radio Round Indicators for Deactivated Fl_Check_Buttons and Fl_Radio_Round_Buttons New RFE
-
-
-
-3210 FLTK 1.3.3 indentation fixed fluid version Core Library Pending RFE
-
-
-
-3211 Scrolling Tabs Widget New RFE
-
-
-
-3218 method for deleting child from a Fl_Group New RFE
-
-
-
-3224 add CMake package registry option New RFE
-
-
-
-3229 X11 dual clipboard control X11 New RFE
-
-
-
-3240 Fl_Html_View - more capable replacement for Fl_Help_View New RFE
-
-
-
-3258 Why not using c++ style of enumeration constants? New RFE
-
-
-
-3260 FLTK's glut and special key combinations on OS X New RFE
-
-
-
-3277 Fl_Text_Display virtual method Core Library New RFE
-
-
-
-3279 RFE: option to disable special character handling in menus Core Library New RFE
-
-
-
-3313 Speedup fl_read_image() for X11 New RFE
-
-
-
-3317 Fl_Sys_Menu_Bar: needs documentation caveats Core Library New RFE
-
-
-
-3329 Support for tablet features (pen pressure, tilt, etc) Core Library New RFE
-
-
-
-3330 Fl_Window transparency control in FLTK Core Library New RFE
-
-
-
-3336 Include some example fluid files Example Programs New RFE
-
-
-
-3350 Some fix to handle dll multi injection and ejection New RFE
-
+
-
-
+
-FLTK 1.4 will add even more features to the FLTK 1 branch.
-
-
-
-
-
-1869 avoid recursing event handlers (Fl::readqueue, Fl::check) New HIGH
-
-
-
-1986 X-server freezes when a window is opened while the menu is open X11 Pending HIGH
-
-
-
-2531 Fl_Text_Display proportional text wobbles when selected on OS X New HIGH
-
-
-
-2634 fl_help_view bug fixes and new features New HIGH
-
-
-
-2639 Fl_Pack resizes hidden widgets, which it doesn't touch when visible. Core Library New HIGH
-
-
-
-2678 internationalization (fluid) FLUID New HIGH
-
-
-
-2861 Enabling "Extract gettext" on fluid menus + possibility of static initialization of strings FLUID New HIGH
-
-
-
-3231 editor.cxx: changed_cb() inducing reading uninitialized memory Example Programs Pending HIGH
-
-
-
-3238 Fl_Group::clear method should be virtual Core Library New HIGH
-
-
-
-3242 Re-enable nested (aka "recursive") common dialogs Core Library Active HIGH
-
-
-
-3271 Socket for MS-WINDOWS is UINT_PTR Core Library New HIGH
-
-
-
-3284 Cairo integration needs redesign Cairo New HIGH
-
-
-
-3289 Fl_Menu_Items don't have i18n function in them when spit from fluid FLUID New HIGH
-
-
-
-3327 Public members Fl::awake_ring_*_ should be private Core Library New HIGH
-
-
-
-24 Fluid should support sub-windows FLUID Pending MOD
-
-
-
-1650 relative widget image path is uncorrect if fl file not saved where created FLUID New MOD
-
-
-
-1859 Fluid callbacks in declaration blocks not working correctly FLUID New MOD
-
-
-
-1919 Fl_Tile uses resizable() interface for different functionality None New MOD
-
-
-
-1993 No redraw when dragging windows WIN32 New MOD
-
-
-
-2034 function Fl_Preferences::getUserdataPath() creates wrong directories Core Library New MOD
-
-
-
-2112 OSX: changing a window's size() affects size_range() max New MOD
-
-
-
-2131 test/help: The 'search window' doesn't work for text within <PRE> New MOD
-
-
-
-2284 Bad return value handling from "getc" in Fl_BMP_Image c'tor Image Support New MOD
-
-
-
-2306 fltk's use of snprintf() should be hardened -- recommend alternatives Core Library New MOD
-
-
-
-2663 OpenGL overlay bug on Windows 7 + Intel graphics OpenGL New MOD
-
-
-
-3013 Fixes to use of config.h header Core Library New MOD
-
-
-
-3287 Potential array overrun in Fl::get_font() New MOD
-
-
-
-469 Drawing problem when FL_ROUNDED_BOX and Fl_Menu_Button Core Library Active LOW
-
-
-
-702 Fl_Scrollbar increments incorrectly in specific situation Core Library New LOW
-
-
-
-810 Fl_File_Chooser value(const char*) not wholly functional Core Library New LOW
-
-
-
-1115 Windows shown while popup menu was active disappear when the menu is dismissed. WIN32 New LOW
-
-
-
-1190 Drawing glitch in Radio Button Core Library New LOW
-
-
-
-1373 per-window vsync control OpenGL New LOW
-
-
-
-1597 Fl_Help_View: HTML problems with font size + <UL> Core Library New LOW
-
-
-
-1679 Borderless windows on WIN32 do not appear on the taskbar WIN32 New LOW
-
-
-
-1742 Fl_Browser: Inconsistent behavior of value() Core Library New LOW
-
-
-
-1860 Would like ability to specify software rendering for OpenGL contexts OpenGL New LOW
-
-
-
-1921 Current
- definition of fl_begin_offscreen() and fl_end_offscreen() makes
-impossible to divide offscreen drawing procedure to a set of
-subsequently called functions New LOW
-
-
-
-1925 Fl_Text_Display should have a member for secondary selection color Core Library New LOW
-
-
-
-1997 fl_file_chooser(...) has a glitch New LOW
-
-
-
-2132 Fluid's Write Code shortcut does not work New LOW
-
-
-
-2145 FL_ROUND_UP_BOX+Fl_Button+"gtk+" scheme: focus box draws outside widget New LOW
-
-
-
-2234 Fl_Text_Editor defaults to DOWN FRAME Core Library Pending LOW
-
-
-
-2251 Fl_Pack resize() and draw() behavior should be improved Core Library New LOW
-
-
-
-2617 Inconsistent behavior for Fl_Window on win32 Core Library New LOW
-
-
-
-2658 set_fonts() comments New LOW
-
-
-
-3179 Opening a popup dialog while a menu is open hangs X X11 Pending LOW
-
-
-
-3344 fluid's New->Code->Code should show .cxx file line#s New LOW
-
-
-
-45 Help_View does not handle tables with border properly (and more) Core Library New RFE
-
-
-
-214 function objects for callbacks. Core Library Pending RFE
-
-
-
-275 fl_ask, fl_alert, fl_file_chooser, fl_* positioning Core Library Active RFE
-
-
-
-298 FLUID "commenting out" would be nice FLUID New RFE
-
-
-
-334 technical change : remove statics in fl_ask Core Library Active RFE
-
-
-
-370 warn, if image format is not compiled in, but applicationattempts to read Image Support Pending RFE
-
-
-
-460 Provide save() member function to Fl_Image subclasses Image Support Pending RFE
-
-
-
-470 up / down indicator when portion of menu is off screen Core Library Pending RFE
-
-
-
-749 Enable a right-click copy/paste menu for all Input/Output/Editor/Display widgets New RFE
-
-
-
-767 Removeing titlebar but keeping border.(win32) New RFE
-
-
-
-900 Fl::add_timeout will also consume all the time of embedded low speed CPU New RFE
-
-
-
-1029 Fl::font(), Fl::size(), etc. for changing defaults New RFE
-
-
-
-1903 Check for missing functionalities from original UTF8 patch Unicode support New RFE
-
-
-
-1923 Enhance non-modal windows on Mac OS X New RFE
-
-
-
-1928 Consider deriving Fl_Label from Fl_Widget Core Library New RFE
-
-
-
-1981 [PATCH] Add "stay on top"-feature to Fl_Window New RFE
-
-
-
-1984 provide a hook to override default event delivery New RFE
-
-
-
-1989 Support for Multiple Cursor interaction (MPX) New RFE
-
-
-
-2014 Digital Mars C++ support for FLTK 1.3 New RFE
-
-
-
-2022 Deriving from Fl_Chart New RFE
-
-
-
-2041 Addition of a FL_TOOLTIP event (PoC) Core Library Pending RFE
-
-
-
-2059 Support for CDash New RFE
-
-
-
-2060 fluid should rewrite files conservatively on "Write Code" FLUID New RFE
-
-
-
-2081 add opengl 3 support to fltk New RFE
-
-
-
-2083 Add maximize, minimize caps to FL_Window Core Library New RFE
-
-
-
-2118 Multisample support on Windows New RFE
-
-
-
-2148 Use iconv() if provided by glibc OS support New RFE
-
-
-
-2154 Support XIM on UTF-8 and GBK locale, update XIM support on GB2312. Unicode support New RFE
-
-
-
-2162 [PATCH] Wrap CJK characters in Fl_Input_ Unicode support New RFE
-
-
-
-2175 why dose not FLTK support framebuffer directly? New RFE
-
-
-
-2177 Fl::add_handler() additional data parameter Core Library New RFE
-
-
-
-2178 Allow Fl_X::make_xid() to call user defined function Core Library New RFE
-
-
-
-2179 Allow receiving events before FLTK handles them Core Library New RFE
-
-
-
-2180 pkg-config support Config Files New RFE
-
-
-
-2188 [PATCH] Support win32 accessibility via MSAA WIN32 New RFE
-
-
-
-2242 Enable usage of FLTK fonts in cairo context (patch included) Cairo New RFE
-
-
-
-2314 Width option for the Fl_Menu_Item Core Library New RFE
-
-
-
-2338 Propose to add a new method to Fl_Widget Fl_Widget::parent_root() New RFE
-
-
-
-2340 Allow setting both a window icon and a mask pixmap in the X11 version. New RFE
-
-
-
-2402 Widget Associations New RFE
-
-
-
-2411 ICC Colour management policy New RFE
-
-
-
-2445 Small modification to Fl_Value_Input to allow precize steps with left mouse button New RFE
-
-
-
-2446 Allow easy customization for special purposes New RFE
-
-
-
-2453 Enable cups printing on unix platforms (include a patch) New RFE
-
-
-
-2454 Fl_Tree: need to fix keyboard nav of *child fltk widgets* added to tree Core Library New RFE
-
-
-
-2482 glutKeyboardUpFunc, glutSpecialUpFunc, glutLeaveMainLoop GLUT Emulation New RFE
-
-
-
-2494 Patch that adds some macros to the extra code lines New RFE
-
-
-
-2583 transparency for fl_draw_image() Core Library New RFE
-
-
-
-2584 A timer to make tooltips hide themselves after a period of time Core Library New RFE
-
-
-
-2586 Consolidate fluid settings into one dialog FLUID New RFE
-
-
-
-2609 shape functions (fl_rectf etc.) support alpha New RFE
-
-
-
-2610 Add another method for Fl_Menu_Button to allow popup at specific position New RFE
-
-
-
-2624 Placement of widgets be Group relative New RFE
-
-
-
-2633 New methods for Fl_JPEG_Image and Fl_PNG_Image to encode from Fl_Image New RFE
-
-
-
-2642 Need examples and docs for how to build apps against DLL version of FLTK Core Library New RFE
-
-
-
-2662 Docs for "Drawing Things In FLTK" should cover coordinate space of widgets vs. windows New RFE
-
-
-
-2669 Fluid Enhancement To Indicate Active Widgets New RFE
-
-
-
-2675 Patch for a new "oxy" theme of FLTK 1.3 (with gradient). Core Library Pending RFE
-
-
-
-2692 right justify option for scroll window Core Library New RFE
-
-
-
-2750 Separate Fl_Input_Choice.H to Fl_Input_Choice.cxx Core Library New RFE
-
-
-
-2751 Limit input field characters in fl_ask, fl_input and friends. Core Library Active RFE
-
-
-
-2752 Allow down arrow to open input-choice drop down menu Core Library New RFE
-
-
-
-2761 Force break when wrapping long words Core Library New RFE
-
-
-
-2762 Ability to set icon character for fl_choice Core Library New RFE
-
-
-
-2776 Separate Fl_Spinner.H to Fl_Spinner.cxx Core Library New RFE
-
-
-
-2785 Evalayout with FLTK one attempt New RFE
-
-
-
-2822 Fl_Input UTF-8 handling Unicode support New RFE
-
-
-
-2916 Remove CMake or Autotools build system Build Files New RFE
-
-
-
-2951 DoubleSlider for selecting low and high values within min/max range Core Library New RFE
-
-
-
-2982 Cannot build outside of source tree. Build Files New RFE
-
-
-
-3100 [patch] Allow printing to be disabled Build Files New RFE
-
-
-
-3160 Fl_Cairo_Window constructors Cairo New RFE
-
-
-
-3204 Fl_Shared_Image improvements Core Library New RFE
-
-
-
-3222 Make the text box area of Fl_Value_Slider etc. user settable Core Library New RFE
-
-
-
-3241 Suggesting int Fl_Menu_::value(item) return -1 if item is in a submenu Core Library New RFE
-
-
-
-3264 The autotools build system does not build FLTKConfig.cmake New RFE
-
-
-
-3288 Consistent configuration macros Config Files New RFE
-
-
-
-3296 Improvement of bilinear scaling of images New RFE
-
-
-
-3297 New implementation of Fl_Shared_Image... New RFE
-
-
-
-3309 Use pango to draw UTF-8 text under X11+Xft X11 New RFE
-
-
-
-3314 Make some private Fl_Tabs methods protected New RFE
-
-
-
-3320 support for high resolution displays on the X11 platform X11 New RFE
-
-
-
-3339 fltk-config: would be nice if one could add extra libs to --compile Config Files New RFE
-
-
-
-3345 SVG image support Image Support New RFE
-
-
-
-3347 prefixing embedded jpeg/png/zlib symbols New RFE
-
-
-
-3351 optionally changing Fl_Choice's dropdown behavior New RFE
-
-
-
-
-
\ No newline at end of file
+
+
diff --git a/documentation/src/fltk-book.tex.in b/documentation/src/fltk-book.tex.in
index 13361ba24..7164687b6 100644
--- a/documentation/src/fltk-book.tex.in
+++ b/documentation/src/fltk-book.tex.in
@@ -1,44 +1,137 @@
-\documentclass[a4paper]{book}
-\usepackage{a4wide}
-\usepackage{makeidx}
-\usepackage{fancyhdr}
+% Latex header for FLTK generated by doxygen 1.8.13
+\batchmode
+\documentclass[twoside]{book}
+
+% Packages required by doxygen
+\usepackage{fixltx2e}
+\usepackage{calc}
+\usepackage{doxygen}
+\usepackage[export]{adjustbox} % also loads graphicx
\usepackage{graphicx}
+\usepackage[utf8]{inputenc}
+\usepackage{makeidx}
\usepackage{multicol}
-\usepackage{float}
+\usepackage{multirow}
+\PassOptionsToPackage{warn}{textcomp}
\usepackage{textcomp}
-\usepackage{alltt}
-\usepackage{times}
+\usepackage[nointegrals]{wasysym}
+\usepackage[table]{xcolor}
+
+% Font selection
+\usepackage[T1]{fontenc}
+\usepackage[scaled=.90]{helvet}
+\usepackage{courier}
+\usepackage{amssymb}
+\usepackage{sectsty}
+\renewcommand{\familydefault}{\sfdefault}
+\allsectionsfont{%
+ \fontseries{bc}\selectfont%
+ \color{darkgray}%
+}
+\renewcommand{\DoxyLabelFont}{%
+ \fontseries{bc}\selectfont%
+ \color{darkgray}%
+}
+\newcommand{\+}{\discretionary{\mbox{\scriptsize$\hookleftarrow$}}{}{}}
+
+% Page & text layout
+\usepackage{geometry}
+\geometry{%
+ a4paper,%
+ top=2.5cm,%
+ bottom=2.5cm,%
+ left=2.5cm,%
+ right=2.5cm%
+}
+\tolerance=750
+\hfuzz=15pt
+\hbadness=750
+\setlength{\emergencystretch}{15pt}
+\setlength{\parindent}{0cm}
+\setlength{\parskip}{3ex plus 2ex minus 2ex}
+\makeatletter
+\renewcommand{\paragraph}{%
+ \@startsection{paragraph}{4}{0ex}{-1.0ex}{1.0ex}{%
+ \normalfont\normalsize\bfseries\SS@parafont%
+ }%
+}
+\renewcommand{\subparagraph}{%
+ \@startsection{subparagraph}{5}{0ex}{-1.0ex}{1.0ex}{%
+ \normalfont\normalsize\bfseries\SS@subparafont%
+ }%
+}
+\makeatother
+
+% Headers & footers
+\usepackage{fancyhdr}
+\pagestyle{fancyplain}
+\fancyhead[LE]{\fancyplain{}{\bfseries\thepage}}
+\fancyhead[CE]{\fancyplain{}{}}
+\fancyhead[RE]{\fancyplain{}{\bfseries\leftmark}}
+\fancyhead[LO]{\fancyplain{}{\bfseries\rightmark}}
+\fancyhead[CO]{\fancyplain{}{}}
+\fancyhead[RO]{\fancyplain{}{\bfseries\thepage}}
+\fancyfoot[LE]{\fancyplain{}{}}
+\fancyfoot[CE]{\fancyplain{}{}}
+\fancyfoot[RE]{\fancyplain{}{\bfseries\scriptsize Generated by Doxygen }}
+\fancyfoot[LO]{\fancyplain{}{\bfseries\scriptsize Generated by Doxygen }}
+\fancyfoot[CO]{\fancyplain{}{}}
+\fancyfoot[RO]{\fancyplain{}{}}
+\renewcommand{\footrulewidth}{0.4pt}
+\renewcommand{\chaptermark}[1]{%
+ \markboth{#1}{}%
+}
+\renewcommand{\sectionmark}[1]{%
+ \markright{\thesection\ #1}%
+}
+
+% Indices & bibliography
+\usepackage{natbib}
+\usepackage[titles]{tocloft}
+\setcounter{tocdepth}{3}
+\setcounter{secnumdepth}{5}
+\makeindex
+
+% Hyperlinks (required, but should be loaded last)
\usepackage{ifpdf}
\ifpdf
-\usepackage[pdftex,
- pagebackref=true,
- colorlinks=true,
- linkcolor=blue,
- unicode
- ]{hyperref}
+ \usepackage[pdftex,pagebackref=true]{hyperref}
\else
-\usepackage[ps2pdf,
- pagebackref=true,
- colorlinks=true,
- linkcolor=blue,
- unicode
- ]{hyperref}
-\usepackage{pspicture}
+ \usepackage[ps2pdf,pagebackref=true]{hyperref}
\fi
-\usepackage[utf8]{inputenc}
-\usepackage{doxygen}
-\makeindex
-\setcounter{tocdepth}{1}
-\renewcommand{\footrulewidth}{0.4pt}
+\hypersetup{%
+ colorlinks=true,%
+ linkcolor=blue,%
+ citecolor=blue,%
+ unicode%
+}
+
+% Custom commands
+\newcommand{\clearemptydoublepage}{%
+ \newpage{\pagestyle{empty}\cleardoublepage}%
+}
+
+\usepackage{caption}
+\captionsetup{labelsep=space,justification=centering,font={bf},singlelinecheck=off,skip=4pt,position=top}
+
+%===== C O N T E N T S =====
+
\begin{document}
+
+% Titlepage & ToC
+\hypersetup{pageanchor=false,
+ bookmarksnumbered=true,
+ pdfencoding=unicode
+ }
+\pagenumbering{alph}
\begin{titlepage}
-\vspace*{4.5cm}
-\begin{center}
+\vspace*{5cm}
+\begin{center}%
{\Huge FLTK @FL_VERSION@ Programming Manual}\\
\vspace*{2cm}
-\begin{ImageNoCaption}
- \mbox{\includegraphics[width=6cm]{FL200}}
-\end{ImageNoCaption}\\
+\begin{DoxyImageNoCaption}
+ \mbox{\includegraphics[width=6cm]{FL200.png}}
+\end{DoxyImageNoCaption}\\
\vspace*{2cm}
{\Large
Revision 9 by F. Costantini, D. Gibson, M. Melcher, \\
@@ -46,11 +139,11 @@ A. Schlosser, B. Spitzak, and M. Sweet.}\\
\vspace*{1.5cm}
{\large Copyright 1998-@YEAR@ by Bill Spitzak and others.}\\
\vspace*{0.75cm}
-{\Small
+{\small
This software and manual are provided under the terms of the GNU Library General Public License.}\\
-{\Small
+{\small
Permission is granted to reproduce this manual or any portion for any purpose,}\\
-{\Small
+{\small
provided this copyright and permission notice are preserved.}\\
\vspace*{2.5cm}
{\large Generated by Doxygen @DOXY_VERSION@}\\
@@ -63,3 +156,6 @@ provided this copyright and permission notice are preserved.}\\
\tableofcontents
\clearemptydoublepage
\pagenumbering{arabic}
+\hypersetup{pageanchor=true}
+
+%--- Begin generated contents ---
diff --git a/ide/.gitattributes b/ide/.gitattributes
index 4149f93dc..0f14dbdad 100644
--- a/ide/.gitattributes
+++ b/ide/.gitattributes
@@ -4,6 +4,7 @@
# MS VC files with Windows line endings (crlf)
+*.cmd eol=crlf
*.dsp eol=crlf
*.dsw eol=crlf
*.filters eol=crlf
diff --git a/ide/VisualC2008/cfluid.cmd b/ide/VisualC2008/cfluid.cmd
index 9bf5ba2aa..dcbb1f7b8 100644
--- a/ide/VisualC2008/cfluid.cmd
+++ b/ide/VisualC2008/cfluid.cmd
@@ -1,13 +1,13 @@
-@echo off
-echo Compiling fluid files ...
-pushd .
-cd ../../test
-if "%1"=="/D" goto debugmode
-..\fluid\fluid -c "%1"
-goto end
-
-:debugmode:
-..\fluid\fluidd -c "%2"
-
-:end
-popd
+@echo off
+echo Compiling fluid files ...
+pushd .
+cd ../../test
+if "%1"=="/D" goto debugmode
+..\fluid\fluid -c "%1"
+goto end
+
+:debugmode:
+..\fluid\fluidd -c "%2"
+
+:end
+popd
diff --git a/ide/VisualC2010/cfluid.cmd b/ide/VisualC2010/cfluid.cmd
index 9bf5ba2aa..dcbb1f7b8 100644
--- a/ide/VisualC2010/cfluid.cmd
+++ b/ide/VisualC2010/cfluid.cmd
@@ -1,13 +1,13 @@
-@echo off
-echo Compiling fluid files ...
-pushd .
-cd ../../test
-if "%1"=="/D" goto debugmode
-..\fluid\fluid -c "%1"
-goto end
-
-:debugmode:
-..\fluid\fluidd -c "%2"
-
-:end
-popd
+@echo off
+echo Compiling fluid files ...
+pushd .
+cd ../../test
+if "%1"=="/D" goto debugmode
+..\fluid\fluid -c "%1"
+goto end
+
+:debugmode:
+..\fluid\fluidd -c "%2"
+
+:end
+popd
diff --git a/makesrcdist b/makesrcdist
index 3a20a80f4..a1e415380 100755
--- a/makesrcdist
+++ b/makesrcdist
@@ -17,16 +17,24 @@
# Use a version number as argument, e.g. "1.3.3" or "1.3.4rc2".
# This can be used for local testing.
#
+# Note: the release tarballs will be created from the current
+# 'HEAD' revision of your local Git repository.
+#
# (3) Create distribution tarballs (final):
#
# makesrcdist tag
#
-# Same as (2), but create subversion tag with version number.
+# Same as (2), but create Git tag with version number.
# Enter "tag" (verbatim) as 2nd argument.
-# This will create the subversion tag "release-" for the
-# current revision in the FLTK subversion repository and export the
+# This will create the Git tag "release-" for the
+# current revision in the (local) FLTK Git repository and export the
# FLTK sources from this tag for creation of distribution files.
#
+# Note: You need to 'git push' the Git tag manually when you
+# are satisfied with the result. You may use:
+# $ git push origin release-
+# where '' is the version number (argument #1)
+#
# Note: define FLTK_TAR if you want to use a different compatible tar
# command than "tar", e.g. to use "gtar" (bash syntax):
# $ export FLTK_TAR="gtar"
@@ -37,25 +45,28 @@ if test "x$FLTK_TAR" != "x"; then
TAR="$FLTK_TAR"
fi
-# these are the subversion and snapshot/download URL's currently in use:
+# These are the release and snapshot download URL's currently in use:
-SVN='http://seriss.com/public/fltk/fltk'
DOWNLOAD='http://fltk.org/pub/fltk'
SNAPSHOT='http://fltk.org/pub/fltk/snapshots'
-VS=`cat VERSION | sed -e's/\([0-9]*\.[0-9]*\).*/\1/'`
+
+DATE="`date +'%Y%m%d'`"
+
+# VS = short version number ('major.minor'), for instance '1.4'.
+# Note: VS is used only for snapshot generation
+
+VS="`cat VERSION | sed -e's/\([0-9]*\.[0-9]*\).*/\1/'`"
echo "Getting distribution..."
if test $# = 0 -o "x$1" = "xsnapshot"; then
- echo Updating for snapshot...
- svn up
- rev=`svnversion . | sed -e '1,$s/[a-zA-Z]//g'`
- version="${VS}svn"
- fileversion="${VS}.x-r$rev"
+ echo Getting snapshot revision...
+ rev="`git rev-parse --short=8 HEAD`"
+ version="${VS}-git"
+ fileversion="${VS}.x-${DATE}-$rev"
fileurl="$SNAPSHOT/fltk-$fileversion.tar.gz"
echo "fileversion = $fileversion"
echo "fileurl = $fileurl"
- url="."
else
if test ! -e "documentation/html/"; then
echo "ERROR: Please generate the HTML documentation before distributing:"
@@ -76,19 +87,16 @@ else
fileversion=$1
fileurl="$DOWNLOAD/$version/fltk-$fileversion-source.tar.gz"
- if test "x$2" != "xtag"; then
- url="."
- else
- echo "Creating subversion tag 'release-$version' ..."
- url="$SVN/tags/release-$version"
- svn copy $SVN/branches/branch-${VS} "$url" \
- -m "Tag $version" || exit 1
+ if test "x$2" = "xtag"; then
+ echo "Creating Git tag 'release-$version' ..."
+ git tag -a -m "Tag $version" release-$version || exit 1
fi
fi
-echo Exporting $version...
+echo Exporting $version to /tmp/fltk-$version/...
rm -rf /tmp/fltk-$version
-svn export $url /tmp/fltk-$version
+mkdir /tmp/fltk-$version
+git archive --format=tar HEAD | $TAR -C /tmp/fltk-$version -x --
if test $# != 0 -a "x$1" != "xsnapshot"; then
echo "Copying HTML and PDF documentation..."
@@ -113,7 +121,6 @@ automake --add-missing --copy
echo Cleaning developer files...
rm -rf OpenGL autom4te* bc5 config forms glut images packages themes
-rm -f makesrcdist
cd ..
@@ -143,4 +150,13 @@ echo "Removing distribution directory..."
rm -rf fltk-$version
+if test "x$2" = "xtag"; then
+ echo ""
+ echo "Don't forget to push the Git tag"
+ echo "(assuming 'origin' as your remote Git repository):"
+ echo ""
+ echo "\$ git push origin release-$version"
+ echo ""
+fi
+
echo "Done!"
diff --git a/test/sudoku.rc b/test/sudoku.rc
index 107c9a69f..7c60e0e05 100644
--- a/test/sudoku.rc
+++ b/test/sudoku.rc
@@ -1,72 +1,72 @@
-//Microsoft Developer Studio generated resource script.
-//
-#include "sudokurc.h"
-
-#define APSTUDIO_READONLY_SYMBOLS
-/////////////////////////////////////////////////////////////////////////////
-//
-// Generated from the TEXTINCLUDE 2 resource.
-//
-//#include "afxres.h"
-
-/////////////////////////////////////////////////////////////////////////////
-#undef APSTUDIO_READONLY_SYMBOLS
-
-/////////////////////////////////////////////////////////////////////////////
-// English (U.S.) resources
-
-#if !defined(AFX_RESOURCE_DLL) || defined(AFX_TARG_ENU)
-#ifdef _WIN32
-//LANGUAGE LANG_ENGLISH, SUBLANG_ENGLISH_US
-#pragma code_page(1252)
-#endif //_WIN32
-
-#ifdef APSTUDIO_INVOKED
-/////////////////////////////////////////////////////////////////////////////
-//
-// TEXTINCLUDE
-//
-
-1 TEXTINCLUDE DISCARDABLE
-BEGIN
- "icons.h\0"
-END
-
-3 TEXTINCLUDE DISCARDABLE
-BEGIN
- "\r\n"
- "\0"
-END
-
-2 TEXTINCLUDE DISCARDABLE
-BEGIN
- "#include ""afxres.h""\r\n"
- "\0"
-END
-
-#endif // APSTUDIO_INVOKED
-
-
-/////////////////////////////////////////////////////////////////////////////
-//
-// Icon
-//
-
-// Icon with lowest ID value placed first to ensure application icon
-// remains consistent on all systems.
-IDI_ICON ICON DISCARDABLE "sudoku.ico"
-#endif // English (U.S.) resources
-/////////////////////////////////////////////////////////////////////////////
-
-
-
-#ifndef APSTUDIO_INVOKED
-/////////////////////////////////////////////////////////////////////////////
-//
-// Generated from the TEXTINCLUDE 3 resource.
-//
-
-
-/////////////////////////////////////////////////////////////////////////////
-#endif // not APSTUDIO_INVOKED
-
+//Microsoft Developer Studio generated resource script.
+//
+#include "sudokurc.h"
+
+#define APSTUDIO_READONLY_SYMBOLS
+/////////////////////////////////////////////////////////////////////////////
+//
+// Generated from the TEXTINCLUDE 2 resource.
+//
+//#include "afxres.h"
+
+/////////////////////////////////////////////////////////////////////////////
+#undef APSTUDIO_READONLY_SYMBOLS
+
+/////////////////////////////////////////////////////////////////////////////
+// English (U.S.) resources
+
+#if !defined(AFX_RESOURCE_DLL) || defined(AFX_TARG_ENU)
+#ifdef _WIN32
+//LANGUAGE LANG_ENGLISH, SUBLANG_ENGLISH_US
+#pragma code_page(1252)
+#endif //_WIN32
+
+#ifdef APSTUDIO_INVOKED
+/////////////////////////////////////////////////////////////////////////////
+//
+// TEXTINCLUDE
+//
+
+1 TEXTINCLUDE DISCARDABLE
+BEGIN
+ "icons.h\0"
+END
+
+3 TEXTINCLUDE DISCARDABLE
+BEGIN
+ "\r\n"
+ "\0"
+END
+
+2 TEXTINCLUDE DISCARDABLE
+BEGIN
+ "#include ""afxres.h""\r\n"
+ "\0"
+END
+
+#endif // APSTUDIO_INVOKED
+
+
+/////////////////////////////////////////////////////////////////////////////
+//
+// Icon
+//
+
+// Icon with lowest ID value placed first to ensure application icon
+// remains consistent on all systems.
+IDI_ICON ICON DISCARDABLE "sudoku.ico"
+#endif // English (U.S.) resources
+/////////////////////////////////////////////////////////////////////////////
+
+
+
+#ifndef APSTUDIO_INVOKED
+/////////////////////////////////////////////////////////////////////////////
+//
+// Generated from the TEXTINCLUDE 3 resource.
+//
+
+
+/////////////////////////////////////////////////////////////////////////////
+#endif // not APSTUDIO_INVOKED
+
diff --git a/src/Fl_GIF_Image.cxx b/src/Fl_GIF_Image.cxx
index 682d251df..97adb23ce 100644
--- a/src/Fl_GIF_Image.cxx
+++ b/src/Fl_GIF_Image.cxx
@@ -3,7 +3,7 @@
//
// Fl_GIF_Image routines.
//
-// Copyright 1997-2015 by Bill Spitzak and others.
+// Copyright 1997-2019 by Bill Spitzak and others.
//
// This library is free software. Distribution and use rights are outlined in
// the file "COPYING" which should have been included with this file. If this
@@ -19,6 +19,16 @@
//
//
+//
+// Reference: GIF89a Specification (links valid as of Jan 05, 2019):
+//
+// "GRAPHICS INTERCHANGE FORMAT(sm), Version 89a" (authoritative):
+// https://www.w3.org/Graphics/GIF/spec-gif89a.txt
+//
+// HTML version (non-authoritative):
+// https://web.archive.org/web/20160304075538/http://qalle.net/gif89a.php
+//
+
//
// Include necessary header files...
//
@@ -113,7 +123,12 @@ Fl_GIF_Image::Fl_GIF_Image(const char *infname) : Fl_Pixmap((char *const*)0) {
uchar ch = NEXTBYTE;
char HasColormap = ((ch & 0x80) != 0);
int BitsPerPixel = (ch & 7) + 1;
- int ColorMapSize = 1 << BitsPerPixel;
+ int ColorMapSize;
+ if (HasColormap) {
+ ColorMapSize = 2 << (ch & 7);
+ } else {
+ ColorMapSize = 0;
+ }
// int OriginalResolution = ((ch>>4)&7)+1;
// int SortedTable = (ch&8)!=0;
ch = NEXTBYTE; // Background Color index
@@ -129,10 +144,6 @@ Fl_GIF_Image::Fl_GIF_Image(const char *infname) : Fl_Pixmap((char *const*)0) {
Green[i] = NEXTBYTE;
Blue[i] = NEXTBYTE;
}
- } else {
- Fl::warning("%s does not have a colormap.", infname);
- for (int i = 0; i < ColorMapSize; i++)
- Red[i] = Green[i] = Blue[i] = (uchar)(255 * i / (ColorMapSize-1));
}
int CodeSize; /* Code size, init from GIF header, increases... */
@@ -179,10 +190,10 @@ Fl_GIF_Image::Fl_GIF_Image(const char *infname) : Fl_Pixmap((char *const*)0) {
GETSHORT(Height);
ch = NEXTBYTE;
Interlace = ((ch & 0x40) != 0);
- if (ch&0x80) {
- // read local color map
- int n = 2<<(ch&7);
- for (i=0; i < n; i++) {
+ if (ch & 0x80) { // image has local color table
+ BitsPerPixel = (ch & 7) + 1;
+ ColorMapSize = 2 << (ch & 7);
+ for (i=0; i < ColorMapSize; i++) {
Red[i] = NEXTBYTE;
Green[i] = NEXTBYTE;
Blue[i] = NEXTBYTE;
@@ -206,6 +217,27 @@ Fl_GIF_Image::Fl_GIF_Image(const char *infname) : Fl_Pixmap((char *const*)0) {
ColorMapSize = 1 << BitsPerPixel;
}
+ // Fix images w/o color table. The standard allows this and lets the
+ // decoder choose a default color table. The standard recommends the
+ // first two color table entries should be black and white.
+
+ if (ColorMapSize == 0) { // no global and no local color table
+ Fl::warning("%s does not have a color table, using default.\n", infname);
+ BitsPerPixel = CodeSize - 1;
+ ColorMapSize = 1 << BitsPerPixel;
+ Red[0] = Green[0] = Blue[0] = 0; // black
+ Red[1] = Green[1] = Blue[1] = 255; // white
+ for (int i = 2; i < ColorMapSize; i++) {
+ Red[i] = Green[i] = Blue[i] = (uchar)(255 * i / (ColorMapSize - 1));
+ }
+#if (0)
+ // fill color table to maximum size
+ for (int i = ColorMapSize; i < 256; i++) {
+ Red[i] = Green[i] = Blue[i] = 0; // black
+ }
+#endif
+ }
+
uchar *Image = new uchar[Width*Height];
int YC = 0, Pass = 0; /* Used to de-interlace the picture */